#!/bin/sh

#
# Copyright (c) 01/05/05 Sun Microsystems, Inc. All Rights Reserved.
#
# ident	"@(#)scm-agent-common.sh	1.7	05/01/05 SMI"
#

#
# The following are the commands used by the scripts
#
PKGINFO=/usr/bin/pkginfo
NEWTASK=/usr/bin/newtask
PROJDEL=/usr/sbin/projdel
PROJADD=/usr/sbin/projadd
PROJMOD=/usr/sbin/projmod
PROJECTS=/usr/bin/projects
POOLBIND=/usr/sbin/poolbind
ACCTADM=/usr/sbin/acctadm
WRACCT=/usr/bin/wracct
MKDIR=/usr/bin/mkdir
PGREP=/usr/bin/pgrep
EGREP=/usr/bin/egrep
GREP=/usr/bin/grep
ECHO=/usr/bin/echo
TAIL=/usr/bin/tail
HEAD=/usr/bin/head
CAT=/usr/bin/cat
CUT=/usr/bin/cut
SED=/usr/bin/sed
AWK=/usr/bin/awk
RM=/usr/bin/rm
CP=/usr/bin/cp
PS=/usr/bin/ps
WC=/usr/bin/wc
ID=/usr/xpg4/bin/id
PRCTL=/usr/bin/prctl

#
# The following are the general files used by scripts
#
PROJECTFILE="/etc/project"
USERATTRFILE="/etc/user_attr"
SCMTMPPROJECTFILE=/tmp/SunMCSCM/tmpProject
SCMTMPUSERATTRFILE=/tmp/SunMCSCM/tmpUserAttr

#
# The following is the temp directory used by Seahaven
#
SCMTMPDIR=/tmp/SunMCSCM

#
# backupProjectFile function takes backup of the /etc/project file
# before we modify it. When the operation is aborted, during the modification,
# we restore the /etc/project file to a state before this operation took place.
#
backupProjectFile() {
    $CP /etc/project /var/opt/SUNWsymon/cfg/scmproject.dat
    if [ $? -ne 0 ]; then
	$ECHO "/etc/project is not backed up properly" > "/dev/stderr"
    fi
}

#
# restoreProjectFile restores the previous copy of the /etc/project file.
#
restoreProjectFile() {
    if [ -d $SCMTMPDIR ]; then
        if [ -x $SCMTMPPROJECTFILE ]; then
            $RM -rf $SCMTMPPROJECTFILE
        fi

	$RM -rf $SCMTMPDIR
    fi
    
    $CP /var/opt/SUNWsymon/cfg/scmproject.dat /etc/project
    if [ $? -ne 0 ]; then
	$ECHO "/etc/project file is not restore correctly." > "/dev/stderr"
    fi

    if [ -f /var/opt/SUNWsymon/cfg/prj_rctl_mod.lock ]; then
	$RM -rf /var/opt/SUNWsymon/cfg/prj_rctl_mod.lock
    fi

    exit 4
}

#
# setTrap function, registers the handle to be executed during interrupts,
# SIGHUP, SIGINT, SIGQUIT, SIGABRT.
#
setTrap() {
    backupProjectFile
    trap restoreProjectFile 1 2 3 6
}

#
# Set the OS version variable
#
setSCMOSVersion() {

    SCMOSVERS=`/usr/bin/uname -r`

    case $SCMOSVERS in
        5.8*)  SCMOSVERS=8 ;;
        5.9*)  SCMOSVERS=9 ;;
        5.10*)  SCMOSVERS=10 ;;
        *) SCMOSVERS=-1 ;;
    esac
}

#
# Set the umask to 022
#
umask 022
