#!/bin/sh

#
# Copyright (c) 01/11/05 Sun Microsystems, Inc. All Rights Reserved.
#
# ident "@(#)scm-setup.sh 1.37     05/01/11 SMI"
#

checkSCMOSVersion() {

    SCMOSVERS=`/usr/bin/uname -r`
    case $SCMOSVERS in
        5.6*)   SCMOSVERS=2.6  ;;
        5.7*)   SCMOSVERS=2.7  ;;
        5.8*)   SCMOSVERS=2.8  ;;
        5.9*)   SCMOSVERS=2.9  ;;
        5.10*)   SCMOSVERS=2.10  ;;
        *)      echolog 'Unsupported OS version: $2' "$SCMOSVERS"
                [ -z "$OS_ERROR" ] && OS_ERROR=96
                exit_SunMC "$OS_ERROR"      ;;
    esac

}

########################################################################
# Function: checkSRM13
# Description: This function checks for SRM1.3 installation, and if not
# 	found, throws appropriate message and exits. The packages checked
#	are SUNWsrmb, SUNWsrmr
# Input : None
# Output: None
########################################################################
checkSRM13 () {
    /usr/bin/pkginfo -qi SUNWsrmb
    srmb_installed=$?

    /usr/bin/pkginfo -qi SUNWsrmr
    srmr_installed=$?

    if [ $srmb_installed -ne 0 -o $srmr_installed -ne 0 ]
    then
        # SRM1.3 is not properly installed
        echolog "Solaris Resource Manager 1.3 is *not* installed correctly."
        echolog "Please install Solaris Resource Manager 1.3 and rerun setup"
        exit 3
    fi
}

########################################################################
# Function: srm8setup
# Description: This function does solaris 8 specifc agent setup
#
# Input :  None
#
# Output: None. 
########################################################################
s8rmsetup()
{
    #
    # Check whether SRM1.3 is installed properly
    #
    checkSRM13

    SRMBASE=`/usr/bin/pkginfo -r SUNWsrmb`
    if [ $? -ne 0 ]
    then
        echolog "Error geting base directory of SRM package SUNWsrmb\n"\
		 > "/dev/stderr"
        exit 3
    fi
    
    if [ `$SRMBASE/srm/sbin/srmadm` != yes ]
    then
        echolog "Solaris Resource Manager not loaded." > "/dev/stderr"
        exit 3
    fi

    # delete group.staff from /etc/project
    /usr/bin/grep "^group.staff:" /etc/project > /dev/null
    if [ $? -eq 0 ]
    then
        /usr/sbin/projdel group.staff > "/dev/stderr"
        if [ $? -ne 0 ]
        then
            echolog "Error deleting project group.staff" > "/dev/stderr"
        fi
    fi

    # change the parent of daemon to srmother
    $SRMBASE/srm/sbin/limadm set "sgroup=srmother" daemon > "/dev/stderr"
    if [ $? -ne 0 ]
    then
        echolog "Error updating lnode daemon" > "/dev/stderr"
    fi

    # change the parent of srmidle to srmother
    $SRMBASE/srm/sbin/limadm set "sgroup=srmother" srmidle > "/dev/stderr"
    if [ $? -ne 0 ]
    then
        echolog "Error updating lnode srmidle" > "/dev/stderr"
    fi

    # start rcapd in project mode
    check_mem_cap
    if [ $? -eq 0 ]; then
        $SRMBASE/srm/sbin/rcapadm -E -m project
        if [ $? -ne 0 ]
        then
            echolog "Error running rcapadm" > "/dev/stderr"
            exit 3
        fi
    fi

    check_extd_accounting 
}


########################################################################
# Function: findline
# Description: This function finds a pattern in a file
# Input: 
# Output:
########################################################################
findline()
{
    pattern=$1
    file=$2
    found=`$CMD_GREP -n -e "$pattern" $file`
    if [ -z "$found" ] ; then
        return 1
    else
        return 0
    fi
}

########################################################################
#
# Function: Configure pools on the system
# Description: 
#  a. If /etc/pooladm.conf is present, take a backup
#  b. If active pool configuration present, copy that to /etc/pooladm.conf
#     else discover one 
#  c. Delete the processor sets in /etc/pooladm.conf
#  d. commit the /etc/pooladm.conf file
#  e. Done
#
# Input: None
# Output: None
########################################################################

check_pool_cfg() {
    #
    # Initializations
    #
    default_poolcfg_file="/etc/pooladm.conf"
    active_pool_conf_file="/var/run/pool.state"

    #
    # Take the backup of /etc/pooladm.conf if exists
    # 
    [ -f "${default_poolcfg_file}" ] && $CMD_CP "${default_poolcfg_file}" \
		"${default_poolcfg_file}.scmbak"

    #
    # If the active pool configuration exists, copy that
    # to /etc/pooladm.conf
    #
    if [ -f "${active_pool_conf_file}" ]; then
        $CMD_CP "${active_pool_conf_file}" "${default_poolcfg_file}"
    else
        # S10 does not have pool.state so ignore. Don't show any msg.
        # on s10 discover only if the default file is absent
        # on  s9 discover even if the file exists.
        if [ $version -ne 10 -o ! -f "${default_poolcfg_file}" ]; then
        #
	# There is no active configuration. Discover one
	#
	$CMD_POOLCFG -c discover 2> /dev/null
	[ $? -ne 0 ] && echolog "Pool Configuration discover failed"

	echolog "Setup discovered new pool configuration"
        fi
    fi

    #
    # call the scmeditpoolconf to check for processor sets not associated with
    # any pools
    #

    ${BASEDIR}/addons/SCM/sbin/scmeditpoolconf "${default_poolcfg_file}" check
    STATUS=$?

    if [ $STATUS -ne 0 ]; then
        #
        # We found that there exists atleast one processor set
        # which is not associated with any resource pool
        # Now, ask the user whether it is OK to delete such processor
        # sets. If the user says, YES, then the setup continues,
        # otherwise, the setup exits
        #
        echo " "
        echolog 'The setup found that there exists atleast one processor set'
        echolog 'not associated with any pools. The add-on requires that such'
        echolog 'processor sets be deleted to continue the setup'
        echo " "

        while [ 1 ];
        do
            READ_RESPONSE_ONCE=0
            fetch_response_text "TAG=PRODUCT.SCM:DEL_PSETS" 'Delete processor sets not associated with any pools [y/n]'
            if [ "$answer" = "n" -o "$answer" = "N" ]; then
	        echo " "
	        echolog 'Please delete the processor sets not associated with any pools'
	        echolog 'and re-run the setup'
	        echo " "
    		#
    		# If we had taken the backup of the /etc/pooladm.conf file,
		# revert it back
    		# 
    		[ -f "${default_poolcfg_file}.scmbak" ] && $CMD_CP "${default_poolcfg_file}.scmbak" \
				"${default_poolcfg_file}" && $CMD_RM "${default_poolcfg_file}.scmbak" 
	        return 1
            fi

            if [ "$answer" = "y" -o "$answer" = "Y" ]; then
	        echo " "
	        break;
            else
	        echolog 'Please choose y or n'
	        echo " "
            fi
        done
    fi

    #
    # Call the scmeditpoolconf binary to delete the
    # processor sets that are not associated with any pools,
    # and to make FSS as the scheduling class of all the pools
    #
    # This is introduced to remove errors from using xmllint
    # program
    #
    ${BASEDIR}/addons/SCM/sbin/scmeditpoolconf "${default_poolcfg_file}"

    # Instantiate the configuration.
    $CMD_POOLADM -c
    [ $? -ne 0 ] && echolog "Error while instantiating system configuration..."

    return 0
}

########################################################################
#
# Function: check_mem_cap
# Description: This function checks for memory capping configuration
# If not found, it informs the user about it.
# This is also used by s8rm setup
# it returns 0 if rcap is installed non zero otherwise
#
########################################################################

check_mem_cap () {
    memcap_pkgchk=""

    $CMD_PKGINFO -qi SUNWrcapr
    [ $? -eq 0 ] && memcap_pkgchk="1"

    $CMD_PKGINFO -qi SUNWrcapu
    [ $? -eq 0 ] && memcap_pkgchk="${memcap_pkgchk}2"

    # If both the packages are present, variable value will be "12"
    if [ "$memcap_pkgchk" = "12" ]; then
        # check if rcap daemon is running.
        # This is not required for solaris 8 host.
        # The code to start rcapd is available in s8rmsetup

        if [ "$version" != "8" ]; then
            $CMD_PGREP rcapd > /dev/null 2>&1
            [ $? -ne 0 ] && $CMD_RCAPADM -E
        fi

        return 0
        
    else
        echo " "
        echolog 'The memory capping packages are not available on this host.'
        echolog 'The setup will not be able to configure memory capping '
	echolog 'functionality'
        echo " "
        return 1
    fi
}

########################################################################
#
# Function: check_extd_accounting
# Description: This function checks for the Extended accounting 
#    configuration If the task accounting file is not set, it takes 
#    default
#
########################################################################

check_extd_accounting() {
    #
    # Setting up of the extended accounting involves
    # grepping the hard coded english strings with the
    # output of the acctadm command. If the locale is different
    # the grep command fails, thus failing the setup. To avoid
    # this, set the locale to english and revert it back to original
    # locale after this.
    #
    CURRENT_LANGUAGE=$LC_ALL
    LC_ALL=C
    export LC_ALL
    default_exacct_file="/var/adm/exacct/task"
    exacct_file=""
    #
    # exacct_success values are
    #   0 - Upon Success
    #   1 - Error in Setting the file for exacct
    #   2 - Error in Setting task based accounting
    #   3 - Error in Setting the extended task accounting
    #
    exacct_success=0

    #
    # First get the extended accounting filename, from the acctadm command
    #    Task Accounting:active/inactive
    # 	 Task Accounting File:none/<filename>
    #	 Tracked task resources:none/extended
    #
    task_acct_file=`$CMD_ACCTADM | $CMD_GREP "Task accounting file:" | \
			$CMD_CUT -d: -f2 | $CMD_SED -e "s/ //g"`

    #
    # Now check whether the file is configured/exists. If it is
    # configured and does not exists, create one. If it is not
    # configured, configure now.
    # 
    if [ "$task_acct_file" = "none" ];
    then
	#
	# Construct the filename with the current timestamp.
	# The format for the date command is same as the one
	# in the module file, so that the file names are created
	# consistently. If this format is changed, then the
	# module file, scm-container-d.prc, under procedure,
	# collectCpuExacctInfo{}.
	#
	exacct_file=$default_exacct_file`$CMD_DATE +%b%d\%H\%M\%S\%Y`

	#
	# Now execute the acctadm command to set the filename
	#
	$CMD_ACCTADM -f $exacct_file task
	if [ $? -ne 0 ]; 
	then
	    exacct_success=1
	fi
    else
        #
	# if the $task_acct_file does not exists, create one
	# Here creating is nothing but executing the acctadm
	# command again with that file name. 
	#
	if [ ! -f "$task_acct_file" ]; then
	    $CMD_ACCTADM -f $task_acct_file task

	    if [ $? -ne 0 ]; then
	        exacct_success=1
	    fi
	fi
    fi

    #
    # When we are here, it is possible that, the file exists, but
    # the Task Accounting is inactive. This can happen only in 
    # Solaris 9, where the user can execute the acctadm -D task,
    # and make the task accounting inactive. The -D option does
    # not exists in Solaris 8 SRM1.x, and hence, when the file
    # is configure, the Task Accounting is also configured.
    #
    # Execute the acctadm command to find the Task Accounting status.
    #
    task_acct=`$CMD_ACCTADM | $CMD_GREP "Task accounting:" | \
		$CMD_CUT -d: -f2 | $CMD_SED -e "s/ //g"`

    #
    # If Task Accounting is not active, activate it
    #
    if [ "$task_acct" != "active" ]; then
	#
        # Activate task accounting
	#
        $CMD_ACCTADM -E task
	if [ $? -ne 0 ]; then
	    exacct_success=2
	fi
    fi

    #
    # Now check whether the tracked resources for the task
    # is set to extended, for extended task accounting.
    # If not set, set it.
    #
    tracked_task_res=`$CMD_ACCTADM | $CMD_GREP "Tracked task resources:" | \
			$CMD_CUT -d: -f2 | $CMD_SED -e "s/ //g"`

    #
    # Check if the task base extended accounting is enabled
    #
    if [ "$tracked_task_res" = "none" ]; then
	#
        # Enable the task based extended accounting
	#
        $CMD_ACCTADM -e extended task
	if [ $? -ne 0 ]; then
	    exacct_success=3
	fi
    fi

    #
    # Now, check the overall status of the extended accounting
    # status, and throw the info accordingly.
    #
    #
    # Revert back to the original locale
    #
    LC_ALL=$CURRENT_LANGUAGE
    export LC_ALL

    if [ $exacct_success -eq 0 ]; then
        echolog "Task based extended accounting is successfully enabled"
    else 
	if [ $exacct_success -eq 1 ]; then
	    echolog "Error in setting the file for extended accounting"
	elif [ $exacct_success -eq 2 ]; then
	    echolog "Error in setting the task accounting"
	elif [ $exacct_success -eq 3 ]; then
	    echolog "Error in setting the extended task accounting"
	fi

	echolog "Extended Task accounting Setup failed." 
    fi
}

########################################################################
#
# Function: update_schd_class
# Description: This function checks whether the default 
# schedular class is FSS or not. If not, sets to FSS.
# 
# Input: None
# Output: None
#
########################################################################

update_schd_class ()
{
    def_schd_class=`$CMD_DISPADMIN -d | $CMD_CUT -c1-3`

    if [ "$def_schd_class" != "FSS" ]; then
        # set the default schedular type to FSS 
        $CMD_DISPADMIN -d FSS

        echo " "
	echolog "System default scheduling class is changed to FSS."
        echo " "
    fi
}

########################################################################
#
# Function: change_procs_sched_class
# Description: Moves processes under TS and IA scheduling class to FSS
# 
# Input: None
# Output: None
#
########################################################################
change_procs_sched_class(){
    #
    # Move processes running in TS and IA scheduling class
    # under FSS scheduling class
    #
    $CMD_PRIOCNTL -s -c FSS -i class TS 2>"/dev/null"
    $CMD_PRIOCNTL -s -c FSS -i class IA 2>"/dev/null"

    echolog "Processes under TS and IA scheduling class are moved under FSS"
    echo " "
}


########################################################################
#
# Function: s10rmsetup
# Description: Enable the pools configuration on the system
#
# Input : None
# Output: None
#
########################################################################

s10rmsetup () 
{
    $CMD_POOLADM > /dev/null 2>&1
    if [ $? -ne 0 ]; then
	#
	# Enable the pools
	#
	$CMD_POOLADM -e
    fi
}


########################################################################
#
# Function: s9rmsetup
# Description: Setup Solaris 9 box for SRM
#
# Input : None
# Output: None
#
########################################################################

s9rmsetup () 
{
    #
    # SUNMC has its own libxml2.so library. In Solaris 9 and 10,
    # the libxml2.so comes with the OS installation.  
    # The libxml2.so in Solaris10 has more APIs than SUNMC libxml2.so
    # and the libpool in solaris10 requires those additional APIs.
    # THe LD_LIBRARY_PATH is set in such a way that the sunmc libxml2.so
    # path comes first and then the /usr/lib. Hence, the pool configuration
    # function was failing on solaris10. Here, we unset the LD_LIBRARY_PATH
    # environment variable to fix this problem.
    #
    if [ "$SCMOSVERS" = "2.10" ]
    then
	#
	# Unset the LD_LIBRARY_PATH
	#
	SCMSAVE_LIB_PATH=$LD_LIBRARY_PATH
	LD_LIBRARY_PATH=""
	export LD_LIBRARY_PATH
    fi

    check_pool_cfg
    STATUS=$?

    if [ "$SCMOSVERS" = "2.10" ]
    then
	#
	# Set the LD_LIBRARY_PATH back
	#
	LD_LIBRARY_PATH=$SCMSAVE_LIB_PATH
	export LD_LIBRARY_PATH
    fi

    if [ $STATUS -ne 0 ]
    then
	exit $STATUS
    fi

    check_mem_cap
    check_extd_accounting
    update_schd_class
    change_procs_sched_class
}

########################################################################
# 
# Function: agent_setup
# Description: This function does setup of the agent layer. 
#  All agent related setup code must go inside this function
#
# Input: None
# Output: None
#
########################################################################
agent_setup()
{
    echolog 'Setup for $2 - Agent Layer' "$SCM_PRODUCT_NAME"
    echolog ""

    #
    # First check, whether the agent is running. If so, 
    # we cannot run this setup, and throw an error message
    #

    $CMD_PS -aef | $CMD_GREP "esd - init agent" | $CMD_GREP -v grep > /dev/null 2>&1
    if [ $? -eq 0 ] ; then
	echolog "agent is currently running. stop the agent before the setup"
        exit 3
    fi

    #
    # Check for lower versions of Solaris.
    #
    version=`$CMD_ECHO $SCMOSVERS | awk -F. '{print $2}'`

    #
    # if the OS is solaris 8, and it is X86, then we
    # will not support seahaven on it. SRM1.3 is not 
    # supported on X86
    #
    if [ $version -lt 8 ] || [ $version -eq 8 -a "$OSARCH" = "i386" ]; then
       echo "***********************************************************"
       multiline_echolog 'You have installed $2 on an\nunsupported operating system. Please check the release\nnotes for information on supported operating systems' "$SCM_PRODUCT_NAME"
       echo "***********************************************************"
       exit 1
    elif [ $version -eq 8 ]; then
        s8rmsetup
    else
	if [ $version -eq 10 ]; then
	    s10rmsetup
	fi

	#
	# For Solaris 9 and up, do the s9 setup.
	#
        s9rmsetup
    fi

    ${BASEDIR}/sbin/es-load-default -a -f ${BASEDIR}/addons/SCM/sbin/scm-container.minfo
    ret=$?
    if [ $ret -ne 0 -a $ret -ne 2 ]; then
        echologverbose 'Could not add the module entry to base-modules-d.dat'
        echolog 'An error occured during the setup of agent layer.'
        echolog '$2 will not be able to manage this agent host' "$SCM_PRODUCT_NAME"
        exit 1
    fi
}


########################################################################
#
# Function: server_setup
# Description: This function does setup of the Server layer. All server 
#    related setup code must go in this function
# 
########################################################################

server_setup()
{
    echolog 'Setup for $2 - Server Layer' "$SCM_PRODUCT_NAME"
    echolog ""
    echolog ""

    setup_service_config_files
}

########################################################################
#
# Function: setup_service_config_files
# Description:
#
########################################################################
setup_service_config_files()
{
    /usr/bin/mkdir -p /var/opt/SUNWsymon/AdvancedServices/services/SCM

    #copy the varopt files
    if [ -f ${BASEDIR}/AdvancedServices/services/SCM/container-service.properties ] ; then
        /usr/bin/cp ${BASEDIR}/AdvancedServices/services/SCM/container-service.properties /var/opt/SUNWsymon/AdvancedServices/services/SCM
    else
        echolog 'Unable to copy file $2 to the /var/opt/SUNWsymon directory' "${BASEDIR}/AdvancedServices/services/SCM/container-service.properties"
        echolog ""
    fi

    if [ -f ${BASEDIR}/AdvancedServices/services/SCM/container-service-acls.properties ] ; then
        /usr/bin/cp ${BASEDIR}/AdvancedServices/services/SCM/container-service-acls.properties /var/opt/SUNWsymon/AdvancedServices/services/SCM
    else
        echolog 'Unable to copy file $2 to the /var/opt/SUNWsymon directory' "${BASEDIR}/AdvancedServices/services/SCM/container-service-acls.properties"
        echolog ""
    fi

    findline scmlog /var/opt/SUNWsymon/AdvancedServices/logs/core/log.properties
    if [ $? -eq 1 ] ; then
        /usr/bin/sed 's/ACTIVE=/ACTIVE=scmlog /' /var/opt/SUNWsymon/AdvancedServices/logs/core/log.properties >  /tmp/log.properties.$$
        /usr/bin/mv /tmp/log.properties.$$ /var/opt/SUNWsymon/AdvancedServices/logs/core/log.properties
        echo "scmlog=clog://localhost/../log/scm.log;lines=1000;width=200;flags=rw+;mode=644;keep=1" >> /var/opt/SUNWsymon/AdvancedServices/logs/core/log.properties
    fi
}


########################################################################
#
# Function: webconsole_setup
# Description: Setup webconsole (Lockhart Console)
#
########################################################################
webconsole_setup() {
    echolog 'Setup for $2 - Web Console' "$SCM_PRODUCT_NAME"
    echolog ""
    echolog ""

    # check lockhart installation
    /usr/bin/pkginfo -q SUNWmcon
    if [ $? -ne 0 ] ; then
	echolog 'Sun Web Console version $2 or above has to be installed' "$REQ_LOCKHART_VERSION"	
	exit 1
    fi
    if [ ! -f /usr/sbin/smcwebserver ]; then
        echolog 'The setup did not find required version of Sun Web Console installed.'
        echolog '$2 needs Sun Web Console version $3 or above' "$SCM_PRODUCT_NAME" "$REQ_LOCKHART_VERSION"
        exit 1
    fi

    
    # If it reaches here, that means it found the binary at expected location.
    # Now check for version if lockhart check flag is true
    if [ "$LOCKHART_CHECK" != "FALSE" ]; then
        lockhart_version=`/usr/sbin/smcwebserver --version | $CMD_AWK '{print $NF}'`
        checkRequiredLockhartVersion "$lockhart_version"
        if [ $? -ne 0 ]; then
            echolog 'The setup did not find required version of Sun Web Console installed.'
            echolog '$2 needs Sun Web Console version $3 or above' "$SCM_PRODUCT_NAME" "$REQ_LOCKHART_VERSION"
            exit 1
        fi
    fi

    currentDir=`pwd`
    cd ${BASEDIR}/addons/SCM/containers/WEB-INF/lib
    [ -h scmca.jar ] && $CMD_RM scmca.jar
    /usr/bin/ln -s ${BASEDIR}/apps/classes/scmca.jar scmca.jar

    # register application
    /usr/sbin/smreg add -d ${BASEDIR}/addons/SCM/containers >/dev/null
    # change startup java parameters
    /usr/sbin/smreg add -p java.options="-server -XX:+BackgroundCompilation -Xmx128M"

    # Precompile the JSPs to speed up the console once the user logs in
    echologverbose 'CATALINA_BASE '${CATALINA_BASE}
    echologverbose 'CATALINA_HOME '${CATALINA_HOME}
    TOMCAT_WORK_DIR=/var/opt/webconsole/work/com_sun_web_console/localhost
    checkInstalledLockhartVersion
    if [ $? -eq 1 ] ; then
        TOMCAT_WORK_DIR=/var/opt/webconsole/work/Standalone/localhost
    fi
    echologverbose $TOMCAT_WORK_DIR
    if [ ! -d "${TOMCAT_WORK_DIR}" ]; then
	/usr/bin/mkdir -p ${TOMCAT_WORK_DIR}
        # Make it writeable by the Tomcat process owner
	/usr/bin/chmod -R 755 /var/opt/webconsole/work
	/usr/bin/chown -R noaccess /var/opt/webconsole/work
    fi	        

    compile_JSPs "${TOMCAT_WORK_DIR}/containers" "${CATALINA_BASE}/containers"
    compile_JSPs "${TOMCAT_WORK_DIR}/console"    "${CATALINA_BASE}/console"

    # register login authentication module
    setupWebConsoleLinks

    # restart webserver
    /usr/sbin/smcwebserver restart >/dev/null
    cd ${currentDir}
}

#
# Checks for the minimum lockhart version requirement
# $1: The detected version of installed lockhart
# Returns 0 If the installed version is -ge REQ_LOCKHART_VERSION
# Returns 1 if a lower version is installed.

checkRequiredLockhartVersion () {
    CURR_VER="$1"

    REQ_VER=`$CMD_ECHO "$REQ_LOCKHART_VERSION" | $CMD_SED -e "s/\./ /g"`
    set $REQ_VER

    REQ_V1=`$CMD_EXPR "$1" \| 0`
    REQ_V2=`$CMD_EXPR "$2" \| 0`
    REQ_V3=`$CMD_EXPR "$3" \| 0`

    CURR_VER=`$CMD_ECHO "$CURR_VER" | $CMD_SED -e "s/\./ /g"`
    set $CURR_VER

    CURR_V1=`$CMD_EXPR "$1" \| 0`
    CURR_V2=`$CMD_EXPR "$2" \| 0`
    CURR_V3=`$CMD_EXPR "$3" \| 0`

    CALC_REQ_VER=`$CMD_EXPR $REQ_V1 \* 100 + $REQ_V2 \* 10 + $REQ_V3`
    CALC_CURR_VER=`$CMD_EXPR $CURR_V1 \* 100 + $CURR_V2 \* 10 + $CURR_V3 2>/dev/null`
    [ $? -ne 0 ] && return 1

    if [ $CALC_CURR_VER -lt $CALC_REQ_VER ]; then
        return 1
    fi

    return 0
}

########################################################################
#
# Function: compile_JSPs
# Description: Precompile the JSPs and put them in a Tomcat specific
#              work directory. This function only compiles the JSPs
#              based on the format relevant to Tomcat 4.0.5. For newer
#              versions, this method will return without doing anything.
#              In Tomcat 5.x, the  class naming has changed from
#              NAME$jsp.java to NAME_jsp.java. This function does not
#              support precompilation for Tomcat 5.x. - Nitin Apr04.
#
########################################################################
compile_JSPs() {
    TOMCAT_CLASS_DIR=$1
    APP_TO_COMPILE=$2
    echologverbose 'Compiling JSPs for application: '${APP_TO_COMPILE}

    VER=`/usr/bin/pkgparam SUNWtcatu VERSION | awk -F, '{print $1}' | awk -F. '{print $1 "." $2}'` ;
    if [ ${VER} != "11.9" ]; then
	echologverbose 'Not a supported Tomcat version for the Sun Management Center JSP Pre-Compilation routine.'
	echologverbose 'Skipping JSP Pre-Compilation.'
	return 1;
    fi;

    /usr/bin/rm -Rf ${TOMCAT_CLASS_DIR}
    /usr/bin/mkdir -p ${TOMCAT_CLASS_DIR}

    ${CATALINA_HOME}/bin/jspc.sh -d ${TOMCAT_CLASS_DIR} -webapp ${APP_TO_COMPILE}

    SRC_DIR=${TOMCAT_CLASS_DIR}
    cd ${SRC_DIR}
    PACKAGE_STRING=package
    COMMENTED_PACKAGE_STRING=//package

    for DIR in `/usr/bin/find $SRC_DIR -type d -name '*'`; do
	cd ${DIR}
	FILE=""
	for FILE in `/usr/bin/ls $DIR/*.java 2> /dev/null`; do
            oldclass=`basename $FILE | sed -e "s/.java//"`
            newclass=${oldclass}'$jsp'
            /usr/bin/sed "s%$PACKAGE_STRING%$COMMENTED_PACKAGE_STRING%g" $FILE > "$FILE"_tmp
            /usr/bin/mv "$FILE"_tmp $FILE

            /usr/bin/echo "package org.apache.jsp;" > ${newclass}.java ;
            /usr/bin/sed -e "/public class/s/${oldclass}/${newclass}/" -e "/public ${oldclass}/s/${oldclass}/${newclass}/" ${oldclass}.java >> ${newclass}.java
            /usr/bin/rm -Rf ${FILE}
	done

       if [ "$FILE" != "" ]; then
	   echologverbose 'Compiling Java files in '${DIR}
	   $JAVA_HOME/bin/javac -classpath ${CATALINA_BASE}/lib/cc.jar:${CATALINA_BASE}/lib/SMIWebConsole.jar:${CATALINA_HOME}/common/lib/servlet.jar:${CATALINA_HOME}/lib/jasper-runtime.jar:${CATALINA_HOME}/lib/com_iplanet_jato_jato.jar:${CLASSPATH} *.java 2> /dev/null

           /usr/bin/rm -Rf *.java
       fi
    done

    # Must be writeable by the user identity of the server process.
    /usr/bin/chmod -R 755 ${TOMCAT_CLASS_DIR}
    /usr/bin/chown -R noaccess ${TOMCAT_CLASS_DIR}
    return 0
}

checkInstalledLockhartVersion() {
   INSTALLED_VERSION=`/usr/sbin/smcwebserver -V | /usr/bin/awk -F' ' '{print $2}'`

     # Minor and micro default to 0 if not specified.
     major=`/usr/bin/echo $INSTALLED_VERSION | /usr/bin/awk -F. '{print $1}'`
    minor=`/usr/bin/echo $INSTALLED_VERSION | /usr/bin/awk -F. '{print $2}'`
     if [ ! -n "$minor" ]; then
         minor="0"
     fi
     micro=`/usr/bin/echo $INSTALLED_VERSION | /usr/bin/awk -F. '{print $3}'`
     if [ ! -n "$micro" ]; then
         micro="0"
     fi

     # The micro version may further be extended to include a patch number.
     # This is typically of the form <micro>_NN, where NN is the 2-digit
     # patch number.  However it can also be of the form <micro>-XX, where
     # XX is some arbitrary non-digit sequence (eg., "rc").  This latter
     # form is typically used for internal-only release candidates or
     # development builds.
     #
     # For these internal builds, we drop the -XX and assume a patch number
     # of "00".  Otherwise, we extract that patch number.
     #
     patch="00"
     dash=`/usr/bin/echo $micro | grep "-"`
     if [ $? -eq 0 ]; then
         # Must be internal build, so drop the trailing variant.
         micro=`/usr/bin/echo $micro | /usr/bin/awk -F- '{print $1}'`
     fi

     underscore=`/usr/bin/echo $micro | grep "_"`
     if [ $? -eq 0 ]; then
         # Extract the seperate micro and patch numbers, ignoring anything
         # after the 2-digit patch.
         patch=`/usr/bin/echo $micro | /usr/bin/awk -F_ '{print substr($2, 1, 2}'`
         micro=`/usr/bin/echo $micro | /usr/bin/awk -F_ '{print $1}'`
     fi

     version="${major}${minor}${micro}${patch}"

     echologverbose "$version"

     if [ $version -lt 21000 ] ; then
         return 1
     fi
     return 0
 }


#*******************************************************************************
#                      MAIN Entry Point
#*******************************************************************************
# Comments:
# This setup script is only intended for Non DB setup (agent & server layer)
#
#*******************************************************************************
SCM_PRODUCT_NAME="N1 Grid Console - Container Manager"
REQ_LOCKHART_VERSION="2.0.2"
CATALINA_HOME_ROOT=`/usr/bin/pkginfo -r SUNWtcatu  2>/dev/null  `
CATALINA_HOME="${CATALINA_HOME_ROOT}/usr/apache/tomcat"
CATALINA_BASE_ROOT=`/usr/bin/pkginfo -r SUNWmcon  2>/dev/null  `
CATALINA_BASE="${CATALINA_BASE_ROOT}/var/opt/webconsole/webapps/"
    
# The following variable will be set using the env variable 
# SCM_LOCKHART_VERSION_CHECK="FALSE"
# this is a private interface for QA in case they use
# lockhart alpha or beta bulid in which the version
# cannot be detected correctly. 
LOCKHART_CHECK="$SCM_LOCKHART_VERSION_CHECK"
BASEDIR=`/usr/bin/pkgparam SUNWescom BASEDIR`
. ${BASEDIR}/SUNWsymon/sbin/es-common.sh

checkSCMOSVersion

checkInstalledLockhartVersion
if [ $? -eq 1 ] ; then
    CATALINA_BASE="${CATALINA_BASE_ROOT}/usr/share/webconsole/"
fi
set_basedir
check_root
set_xput
setup_textdomain SUNW_SUNMC_SCM
CMD_GREP=/usr/bin/egrep
CMD_PGREP="/usr/bin/pgrep"
CMD_PSRSET="/usr/sbin/psrset"
CMD_POOLADM="/usr/sbin/pooladm"
CMD_POOLCFG="/usr/sbin/poolcfg"
CMD_RCAPADM="/usr/sbin/rcapadm"
CMD_ACCTADM="/usr/sbin/acctadm"
CMD_DISPADMIN="/usr/sbin/dispadmin"
CMD_XMLLINT="/usr/bin/xmllint"
CMD_PRIOCNTL=/usr/bin/priocntl
CMD_DATE=/usr/bin/date
CMD_PS=/usr/bin/ps

SCMSAVE_LIB_PATH=$LD_LIBRARY_PATH

umask 022

#
# Process command-line options
#

while getopts L:A: OPT ; do
  case $OPT in
    L)
        # Log file has been passed
        LOGFILE="$OPTARG"
        check_logfile
    ;;

    A)
        # response file
        AUTOCONFIG_RUNFILE="$OPTARG"
        export AUTOCONFIG_RUNFILE

    ;;
  esac
done

#If agent layer is installed, run agent_setup
/usr/bin/pkginfo -q SUNWscma
if [ $? -eq 0 ] ; then
    agent_setup
fi


#if Server layer is installed, run server_setup
/usr/bin/pkginfo -q SUNWscms
if [ $? -eq 0 ] ; then
    server_setup
    webconsole_setup
fi

exit 0

